<?php
namespace Ak\Woo\User\Form\Element;

use Ak\Orm\Repository\RepositoryManager;
use Ak\Wp\Model\Entity\Post;
use Ak\Wp\Model\Entity\PostInterface;
use Ak\Wp\Model\Repository\PostRepository;
use Interop\Container\ContainerInterface;
use Laminas\Form\ElementFactory;
use Laminas\Form\ElementInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu NewsletterSignupCheckboxa.
 *
 * @package Ak\Woo\User\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-user
 */
class NewsletterSignupCheckboxFactory implements FactoryInterface
{
    /** @var PostRepository */
    private $postRepository;

    /**
     * Stvara instancu.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return ElementInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $elementFactory = new ElementFactory();
        /** @var TosAcceptCheckbox $element */
        $element = $elementFactory($container, $requestedName, $options);

        $config = $container->get('config')['woo']['user'] ?? [];

        if (($additionalInfoId = intval($config['newsletter_signup_additional_info_id'] ?? null)) > 0) {
            $posts = $this->getPostRepository($container);
            $post = $posts->find($additionalInfoId);

            if ($post instanceof PostInterface) {
                $element->setAdditionalInfo($post->getContent());
            }
        }

        if (($uncheckWarkingId = intval($config['newsletter_signup_uncheck_warning_id'] ?? null)) > 0) {
            $posts = $this->getPostRepository($container);
            $post = $posts->find($uncheckWarkingId);

            if ($post instanceof PostInterface) {
                $element->setUncheckWarning($post->getContent());
            }
        }

        return $element;
    }

    /**
     * @param ContainerInterface $container
     * @return PostRepository
     */
    private function getPostRepository(ContainerInterface $container): PostRepository
    {
        if (null === $this->postRepository) {
            /** @var RepositoryManager $repositories */
            $repositories = $container->get(RepositoryManager::class);
            /** @var PostRepository $posts */
            $this->postRepository = $repositories->get(Post::class);
        }

        return $this->postRepository;
    }
}
