<?php
namespace Ak\Woo\User\Form\Element;

use Ak\Orm\Repository\RepositoryManager;
use Ak\Wp\Model\Entity\Post;
use Ak\Wp\Model\Entity\PostInterface;
use Ak\Wp\Model\Repository\PostRepository;
use Interop\Container\ContainerInterface;
use Laminas\Form\ElementFactory;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu TosAccept elementa.
 *
 * @package Ak\Woo\User\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-user
 */
class TosAcceptFactory implements FactoryInterface
{
    /**
     * Stvara element.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TosAcceptCheckbox
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $elementFactory = new ElementFactory();
        /** @var TosAcceptCheckbox $element */
        $element = $elementFactory($container, $requestedName, $options);

        $config = $container->get('config')['woo']['user'] ?? [];

        if (($additionalInfoId = intval($config['tos_accept_additional_info_id'] ?? null)) > 0) {
            /** @var RepositoryManager $repositories */
            $repositories = $container->get(RepositoryManager::class);
            /** @var PostRepository $posts */
            $posts = $repositories->get(Post::class);
            $post = $posts->find($additionalInfoId);

            if ($post instanceof PostInterface) {
                $element->setAdditionalInfo($post->getContent());
            }
        }

        return $element;
    }
}
