<?php
namespace Ak\Woo\User\Plugin;

use Ak\Form\FormElementManager;
use Ak\Orm\Repository\RepositoryManager;
use Ak\Form\View\Helper\FormControl;
use Ak\Gdpr\Entity\GdprConsent;
use Ak\Wp\Plugin\PluginInterface;
use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Laminas\ServiceManager\PluginManagerInterface;

/**
 * Stvara novu instancu Registration plugina.
 *
 * @package Ak\Woo\User\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-user
 */
class RegistrationFactory implements FactoryInterface
{
    /**
     * Stvara instancu.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return PluginInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['woo']['user'] ?? [];

        /** @var PluginManagerInterface $forms */
        $forms = $container->get(FormElementManager::class);

        /** @var PluginManagerInterface $helpers */
        $helpers = $container->get('ViewHelperManager');
        /** @var FormControl $helper */
        $helper = $helpers->get(FormControl::class);

        /** @var PluginManagerInterface $repos */
        $repos = $container->get(RepositoryManager::class);
        $gdprRepo = $repos->get(GdprConsent::class);

        $mailingLists = $container->get('mailchimp.lists');

        return new Registration($config, $forms, $helper, $gdprRepo, $mailingLists);
    }
}
