<?php
namespace AkTest\Woo\User\Form\Element;

use Ak\Form\FormElementManager;
use Ak\Test\AbstractTestCase;
use Ak\Test\FormTestTrait;
use Ak\Woo\User\Form\Element\NewsletterSignupCheckbox;
use Ak\Wp\Model\Entity\Post;
use Ak\Wp\Model\Repository\PostRepository;
use AkTest\Woo\User\TestConfigProvider;
use Laminas\InputFilter\Factory;
use WP_Post;

/**
 * Class NewsletterSignupCheckboxTest
 *
 * @package AkTest\Woo\User\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-user
 */
class NewsletterSignupCheckboxTest extends AbstractTestCase
{
    use FormTestTrait;

    public $configProviders = [
        TestConfigProvider::class,
    ];

    public function testIsRegistered()
    {
        $formElements = $this->getFormElementManager();

        $this->assertTrue($formElements->has(NewsletterSignupCheckbox::class));
        $this->assertInstanceOf(NewsletterSignupCheckbox::class, $formElements->get(NewsletterSignupCheckbox::class));
    }

    public function testHasTheCorrectLabel()
    {
        /** @var NewsletterSignupCheckbox $element */
        $element = $this->getFormElement(NewsletterSignupCheckbox::class);

        $this->assertStringContainsString('želim', $element->getLabel());
        $this->assertStringContainsString('newsletter', $element->getLabel());
    }

    public function testIsNotRequired()
    {
        $inputFactory = new Factory();

        /** @var NewsletterSignupCheckbox $element */
        $element = $this->getFormElement(NewsletterSignupCheckbox::class);
        $input = $inputFactory->createInput($element->getInputSpecification());

        $this->assertFalse($input->isRequired());
    }

    public function testAdditionalInfoIsInjected()
    {
        $post = new Post(new WP_Post((object) [
            'post_content' => 'post content',
        ]));

        $container = $this->getContainer([
            'repositories' => [
                'factories' => [
                    PostRepository::class => function() use ($post) {
                        $repo = $this->createMock(PostRepository::class);
                        /** @noinspection PhpParamsInspection */
                        $repo->expects($this->once())
                            ->method('find')
                            ->with(4657)
                            ->willReturn($post);
                        return $repo;
                    }
                ],
            ],

            'woo' => [
                'user' => [
                    'newsletter_signup_additional_info_id' => 4657,
                ],
            ],
        ]);

        /** @var FormElementManager $formElements */
        $formElements = $container->get(FormElementManager::class);

        /** @var NewsletterSignupCheckbox $element */
        $element = $formElements->get(NewsletterSignupCheckbox::class);

        $this->assertEquals('post content', $element->getAdditionalInfo());
    }

    public function testUncheckWarningIsInjected()
    {
        $post = new Post(new WP_Post((object) [
            'post_content' => 'post content',
        ]));

        $container = $this->getContainer([
            'repositories' => [
                'factories' => [
                    PostRepository::class => function() use ($post) {
                        $repo = $this->createMock(PostRepository::class);
                        /** @noinspection PhpParamsInspection */
                        $repo->expects($this->once())
                            ->method('find')
                            ->with(4657)
                            ->willReturn($post);
                        return $repo;
                    }
                ],
            ],

            'woo' => [
                'user' => [
                    'newsletter_signup_uncheck_warning_id' => 4657,
                ],
            ],
        ]);

        /** @var FormElementManager $formElements */
        $formElements = $container->get(FormElementManager::class);

        /** @var NewsletterSignupCheckbox $element */
        $element = $formElements->get(NewsletterSignupCheckbox::class);

        $this->assertEquals('post content', $element->getUncheckWarning());
    }

    public function testIsCheckedByDefault()
    {
        /** @var NewsletterSignupCheckbox $element */
        $element = $this->getFormElement(NewsletterSignupCheckbox::class);

        $this->assertTrue($element->isChecked());
    }
}
