<?php
namespace AkTest\Woo\User\Form\Element;

use Ak\Form\FormElementManager;
use Ak\Test\AbstractTestCase;
use Ak\Test\FormTestTrait;
use Ak\Woo\User\Form\Element\TosAcceptCheckbox;
use Ak\Woo\User\Validator\TosAccept as TosAcceptValidator;
use Ak\Wp\Model\Entity\Post;
use Ak\Wp\Model\Repository\PostRepository;
use AkTest\Woo\User\TestConfigProvider;
use Laminas\Form\Form;
use Laminas\InputFilter\Factory;
use WP_Post;

/**
 * Class TosAcceptCheckboxTest
 *
 * @package AkTest\Woo\User\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-user
 */
class TosAcceptCheckboxTest extends AbstractTestCase
{
    use FormTestTrait;

    public $configProviders = [
        TestConfigProvider::class,
    ];

    public function testIsRegistered()
    {
        $formElements = $this->getFormElementManager();

        $this->assertTrue($formElements->has(TosAcceptCheckbox::class));
        $this->assertInstanceOf(TosAcceptCheckbox::class, $formElements->get(TosAcceptCheckbox::class, 'tos_accept'));
    }

    public function testDoesntUseHiddenElement()
    {
        $formElements = $this->getFormElementManager();

        /** @var TosAcceptCheckbox $element */
        $element = $formElements->get(TosAcceptCheckbox::class, 'tos_accept');

        $this->assertFalse($element->useHiddenElement());
    }

    public function testElementHasTheCorrectLabel()
    {
        $formElements = $this->getFormElementManager();

        /** @var TosAcceptCheckbox $element */
        $element = $formElements->get(TosAcceptCheckbox::class, 'tos_accept');

        $this->assertContains('rihvaća', $element->getLabel());
        $this->assertContains('uvjet', $element->getLabel());
    }

    public function testInputSpecIsCorrect()
    {
        /** @var TosAcceptCheckbox $element */
        $element = $this->getFormElement(TosAcceptCheckbox::class, 'tos_accept');

        $factory = new Factory();
        $input = $factory->createInput($element->getInputSpecification());
        $validators = $input->getValidatorChain()->getValidators();

        $this->assertEquals($element->getName(), $input->getName());
        $this->assertCount(1, $validators);
        $this->assertInstanceOf(TosAcceptValidator::class, $validators[0]['instance']);
        $this->assertTrue($input->isRequired());
    }

    public function testAdditionalInfoIsInjected()
    {
        $post = new Post(new WP_Post((object) [
            'post_content' => 'post content',
        ]));

        $container = $this->getContainer([
            'repositories' => [
                'factories' => [
                    PostRepository::class => function() use ($post) {
                        $repo = $this->createMock(PostRepository::class);
                        /** @noinspection PhpParamsInspection */
                        $repo->expects($this->once())
                            ->method('find')
                            ->with(4657)
                            ->willReturn($post);
                        return $repo;
                    }
                ],
            ],

            'woo' => [
                'user' => [
                    'tos_accept_additional_info_id' => 4657,
                ],
            ],
        ]);

        /** @var FormElementManager $formElements */
        $formElements = $container->get(FormElementManager::class);

        /** @var TosAcceptCheckbox $element */
        $element = $formElements->get(TosAcceptCheckbox::class);

        $this->assertEquals('post content', $element->getAdditionalInfo());
    }

    public function testWillInvalidateWhenInForm()
    {
        $element = $this->getFormElement(TosAcceptCheckbox::class, 'tos_accept');

        $form = new Form();
        $form->add($element);
        $form->setData([]);

        $this->assertFalse($form->isValid());

        $messages = $form->getMessages()['tos_accept'];

        $this->assertCount(1, $messages);
        $this->assertArrayHasKey(TosAcceptValidator::IS_EMPTY, $messages);
    }
}
